/***********************************************************************************************************************/
/* This is the code writen for evaluating the statistical properties of Bayesian point and interval summaries of       */
/* four effect size measures for the mediated effect in the single mediator model with continuous X, M, and Y          */
/* for the manuscript titled "Statistical Properties of Four Effect Size Measures for Mediation Models".               */
/***********************************************************************************************************************/


FILENAME NULLOG DUMMY 'C:\NULL';
PROC PRINTTO LOG=NULLOG;
options nosource nonotes errors=0;

PROC DATASETS LIBRARY=WORK KILL NOLIST; RUN; 
LIBNAME N40 "C:\Desktop"; 
%include 'C:\Desktop\postint.sas';

 
%MACRO SIMULATE(NSIM,NOBS,BMX,BYM,BYX,FILE,TYPE,ERROR,ERRORM,ERRORY);

DATA SUMMARY; SET _NULL_;
%DO I=1 %TO &NSIM;
TITLE 'SIMULATION OF MEDIATION';
DATA SIM;
DO I=1 TO &NOBS;
X=(&error)*RANNOR(0);
M=&BMX*X+(&errorm)*RANNOR(0);
Y=&BYX*X+&BYM*M+(&errory)*RANNOR(0);
X2=X*X;
OUTPUT;
END;


*This code obtains estimates of the mediation regression
equations for the sample generated in the macro program;

*Estimating the (Y=X) regression and saving the value of bm1 or c in the text;
PROC REG DATA=SIM OUTEST=FILE COVOUT NOPRINT; MODEL Y=X/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; BM1=X;MSE1=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y;
KEEP BM1 MSE1;
DATA C; SET FILE;IF _NAME_='X'; SEBM1=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y;
KEEP SEBM1;
DATA MODEL1; MERGE B C;

RUN;
*Estimating the (Y=X M) regression and saving the values of
c prime and b;
PROC REG DATA=SIM OUTEST=FILE COVOUT NOPRINT;
MODEL Y=X M/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; C=X;
BM2=X; MSE2=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP MSE2 BM2 C;
DATA C; SET FILE;
IF _NAME_='X'; SEBM2=SQRT(X); SEC=SQRT(X);
KEEP SEBM2 SEC;
DATA D; SET FILE; IF _NAME_= 'M'; SEB=SQRT(M);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP SEB;
DATA E; SET FILE; B=M; IF _TYPE_='PARMS';
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP B;
DATA F; SET FILE; IF _NAME_='M'; CBC=X;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP CBC;
DATA MODEL2; MERGE B C D E F;

*Estimating the (M=X) regression and saving the value of a;
PROC REG DATA=SIM OUTEST=FILE COVOUT NOPRINT;
MODEL M=X;
DATA BB; SET FILE;
IF _TYPE_='PARMS'; M=X;
BM2=X; MSE3=_RMSE_*_RMSE_;
KEEP MSE3;

DATA B; SET FILE; A=X; IF _TYPE_='PARMS';
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M;
KEEP A;
DATA C; SET FILE; IF _NAME_='X'; SEA=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M;
KEEP SEA;
DATA MODEL3; MERGE BB B C;

*This code saves the variance of X in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR X;
OUTPUT OUT=OUTA STD=VARX;
DATA VARS; SET OUTA;
VARXX=VARX*VARX;
KEEP VARX VARXX;

*This code saves the variance of M in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR M;
OUTPUT OUT=OUTA STD=VARM;
DATA VARSM; SET OUTA;
VARMM=VARM*VARM;
KEEP VARMM;

*This code saves the variance of Y in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR Y;
OUTPUT OUT=OUTA STD=VARY;
DATA VARSY; SET OUTA;
VARYY=VARY*VARY;
KEEP VARY VARYY;

*This code saves the correlation between X and M in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR; SET COV; IF _NAME_='M'; CORRXM=X;
KEEP CORRXM;
*This code saves the correlation between Y and M in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR1; SET COV; IF _NAME_='Y'; CORRMY=M;
KEEP CORRMY;
*This code saves the correlation between Y and X in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR2; SET COV; IF _NAME_='Y'; CORRXY=X;
KEEP CORRXY;

*This code saves the covariance between X and M in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC1; SET COV; IF _TYPE_='COV';IF _NAME_='M'; COVXM=X;
KEEP COVXM;
*This code saves the covariance between Y and M in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC2; SET COV; IF _TYPE_='COV';IF _NAME_='Y'; COVMY=M;
KEEP COVMY;
*This code saves the covariance between Y and X in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC3; SET COV; IF _TYPE_='COV'; IF _NAME_='Y'; COVXY=X;
KEEP COVXY;

*Bayesian computation of effect size measures;
proc mcmc data=SIM outpost=outdiff nbi=2000 nmc=1500 thin=1 seed=2 diag=none plots=none;
parms a 0 b 0 cpr 0 i2 0 i3 0;
parms sigmaem 1 sigmaey 1;
prior a b cpr i2 i3~ normal (mean=0, prec=1e-3);
prior sigmaem sigmaey ~ gamma(shape=0.01, iscale=0.01);
mum=i2+a*X;
muy=i3+b*M+cpr*X;
model M~ n(mum, prec=sigmaem);
model Y~ n(muy, prec=sigmaey);
run;

data abdiff; set outdiff;
ab=a*b;
prop=a*b/(a*b+cpr);
ratio=a*b/cpr;
run;

%let parms = prop ratio;
%postint(data=abdiff, var=&parms, out=HDIpropratio);

data HDIprop; set HDIpropratio;
if Parameter^='prop' then delete;
LETprop=CredibleLower;
UETprop=CredibleUpper;
LHDIprop=HPDLower;
UHDIprop=HPDUpper;
drop CredibleLower CredibleUpper HPDLower HPDUpper;
run;

data HDIratio; set HDIpropratio;
if Parameter^='ratio' then delete;
LETratio=CredibleLower;
UETratio=CredibleUpper;
LHDIratio=HPDLower;
UHDIratio=HPDUpper;
drop CredibleLower CredibleUpper HPDLower HPDUpper;
run;

proc sort data=abdiff out=percentilesdiff;
by prop;
run;
ods output BasicMeasures=Work.measuresprop;
proc univariate data=percentilesdiff nextrobs=0  notabcontents;
var prop;
output out=pdiffprop pctlpre=P_ pctlpts=2.5 97.5;
run; 
data meanprop; set measuresprop;
if LocMeasure^='Mean' then delete;
meanprop=LocValue;
propsd=VarValue;
run;

data medianprop; set measuresprop;
if LocMeasure^='Median' then delete;
medprop=LocValue;
run;

proc sort data=abdiff out=percentilesdiff;
by ratio;
run;

ods output BasicMeasures=Work.measuresratio;
proc univariate data=percentilesdiff nextrobs=0  notabcontents;
var ratio;
output out=pdiffratio pctlpre=P_ pctlpts=2.5 97.5;
run; 

data meanratio; set measuresratio;
if LocMeasure^='Mean' then delete;
meanratio=LocValue;
ratiosd=VarValue;
run;

data medianratio; set measuresratio;
if LocMeasure^='Median' then delete;
medratio=LocValue;
run;

data SIM2; set SIM;
ZX=x;
ZY=y;
run;
PROC STANDARD DATA=SIM2 MEAN=0 STD=1 OUT=ZSIM;
  VAR ZX ZY;
RUN;

PROC MEANS DATA=ZSIM;
RUN;

/*specifying diffuse prior distributions for regression coefficients and variances of M and Y;*/
proc mcmc data=ZSIM outpost=outdiffZ nbi=2000 nmc=2500 thin=1 seed=2 diag=none plots=none;
parms a 0 b 0 cpr 0 i2 0 i3 0;
parms sigmaem 1 sigmaey 1;
prior a b cpr i2 i3~ normal (mean=0, prec=1e-3);
prior sigmaem sigmaey ~ gamma(shape=0.01, iscale=0.01);
mum=i2+a*X;
muy=i3+b*M+cpr*X;
model M~ n(mum, prec=sigmaem);
model ZY~ n(muy, prec=sigmaey);
run;

data abdiffZ; set outdiffZ;
ABPS=a*b;
run;

%let parms = ABPS;
%postint(data=abdiffZ, var=&parms, out=HDIabps);

data HDIABPS; set HDIabps;
if Parameter^='ABPS' then delete;
LETABPS=CredibleLower;
UETABPS=CredibleUpper;
LHDIABPS=HPDLower;
UHDIABPS=HPDUpper;
drop CredibleLower CredibleUpper HPDLower HPDUpper;
run;

proc sort data=abdiffZ out=percentilesdiffZ;
by ABPS;
run;

ods output BasicMeasures=Work.measuresabps;
proc univariate data=percentilesdiffZ nextrobs=0  notabcontents;
var ABPS;
output out=pdiffabZ pctlpre=P_ pctlpts=2.5 97.5;
run; 

data meanabps; set measuresabps;
if LocMeasure^='Mean' then delete;
meanabps=LocValue;
abpssd=VarValue;
run;

data medianabps; set measuresabps;
if LocMeasure^='Median' then delete;
medabps=LocValue;
run;

/*specifying diffuse prior distributions for regression coefficients and variances of M and Y;*/
proc mcmc data=ZSIM outpost=outdiffZZ nbi=2000 nmc=2500 thin=1 seed=2 diag=none plots=none;
parms a 0 b 0 cpr 0 i2 0 i3 0;
parms sigmaem 1 sigmaey 1;
prior a b cpr i2 i3~ normal (mean=0, prec=1e-3);
prior sigmaem sigmaey ~ gamma(shape=0.01, iscale=0.01);
mum=i2+a*ZX;
muy=i3+b*M+cpr*ZX;
model M~ n(mum, prec=sigmaem);
model ZY~ n(muy, prec=sigmaey);
run;

data abdiffZZ; set outdiffZZ;
ABFS=a*b;
run;

%let parms = ABFS;
%postint(data=abdiffZZ, var=&parms, out=HDIabfs);

data HDIABFS; set HDIabfs;
if Parameter^='ABFS' then delete;
LETABFS=CredibleLower;
UETABFS=CredibleUpper;
LHDIABFS=HPDLower;
UHDIABFS=HPDUpper;
drop CredibleLower CredibleUpper HPDLower HPDUpper;
run;

proc sort data=abdiffZZ out=percentilesdiffZZ;
by ABFS;
run;

ods output BasicMeasures=Work.measuresabfs;
proc univariate data=percentilesdiffZZ nextrobs=0  notabcontents;
var ABFS;
output out=pdiffabZZ pctlpre=P_ pctlpts=2.5 97.5;
run; 


data meanabfs; set measuresabfs;
if LocMeasure^='Mean' then delete;
meanabfs=LocValue;
abfssd=VarValue;
run;

data medianabfs; set measuresabfs;
if LocMeasure^='Median' then delete;
medabfs=LocValue;
run;


data Bint; merge hdiprop hdiratio HDIABPS HDIABFS ;
run;


*This code merges the different datasets that contain 
estimates from the simulation replication;

DATA ALL; MERGE MODEL1 MODEL2 MODEL3 VARS VARSM VARSY FR FR1 FR2 FC1 FC2 FC3
meanprop medianprop meanratio medianratio meanabps medianabps meanabfs medianabfs
Bint;
RUN;


*This code calculates the population values for empirical
values estimated in the simulation;
DATA TEST;SET ALL;
TYPE=&TYPE;
ERROR=&ERROR;
DOF=_FREQ_-2;
NOBS=&NOBS;
BMX=&BMX;BYX=&BYX;BYM=&BYM;


*This section computes true variances and covariances based on residual error variance equal to 1;
EMOD1=(&ERROR)**2;
EMOD2=(&ERRORm)**2;
EMOD3=(&ERRORy)**2;
VX1X1=EMOD1; 
CY1X1=BMX*EMOD1;
CY2X1=BYM*BMX*VX1X1+BYX*EMOD1;
CY1Y1=BMX*BMX*VX1X1+EMOD2;
CY2Y1=BMX*BMX*BYM*VX1X1+BMX*BYX*EMOD1+BYM*EMOD2;
CY2Y2=BYM*BYM*(BMX*BMX*EMOD1+EMOD2)+2*BMX*BYM*BYX*VX1X1+BYX*BYX*EMOD1
+EMOD3;
compcp=(cy1y1*cy2x1-cy1x1*cy2y1)/(vx1x1*cy1y1-cy1x1**2);
compb=(vx1x1*cy2y1-Cy1x1*cy2x1)/(vx1x1*cy1y1-cy1x1**2);
;

*The following code computes effect size measures and their biases for the total mediated effect;

*The proportion mediated effect size measure;
AB=A*B;
PROP=AB/(AB+C);
PROPT=BMX*BYM/(BMX*BYM+BYX);
PROPbias=PROP-PROPT;
PROPbiasP=PROPbias/PROPT;
bmeanpropbias=meanprop-PROPT;
bmedpropbias=medprop-PROPT;
bmeanpropbiasP=bmeanpropbias/PROPT;
bmedpropbiasP=bmedpropbias/PROPT;
*The ratio of the indirect to the direct effect effect size measure;
RATIO=AB/C;
RATIOT=BMX*BYM/BYX;
RATIObias=RATIO-RATIOT;
RATIObiasP=RATIObias/RATIOT;
bmeanratiobias=meanratio-RATIOT;
bmedratiobias=medratio-RATIOT;
bmeanratiobiasP=bmeanratiobias/RATIOT;
bmedratiobiasP=bmedratiobias/RATIOT;

*Standardized Effect Size measures ;
DMEAS1=AB/SQRT(VARYY); 

DMEAS2=AB*SQRT(VARXX)/SQRT(VARYY);
TDMEAS1=BMX*BYM/SQRT(CY2Y2); TDMEAS2=BMX*BYM*SQRT(VX1X1)/SQRT(CY2Y2);
BDMEAS1=DMEAS1-TDMEAS1;BDMEAS2=DMEAS2-TDMEAS2;

bmeanabps=meanabps-TDMEAS1;
bmedabps=medabps-TDMEAS1;
bmeanabpsp=bmeanabps/TDMEAS1;
bmedabpsp=bmedabps/TDMEAS1;

bmeanabfs=meanabfs-TDMEAS2;
bmedabfs=medabfs-TDMEAS2;
bmeanabfsp=bmeanabfs/TDMEAS2;
bmedabfsp=bmedabfs/TDMEAS2;


*Evaluation of Bayesian Interval Summaries;

*proportion mediated;
RETalphaprop=0; 
LETalphaprop=0;


IF PROPT=0 && LETprop GT 0 && UETprop GT 0 THEN LETalphaprop=1;
IF PROPT=0 && LETprop LT 0 && UETprop LT 0 THEN RETalphaprop=1;

TYPEIERRORpropET=LETalphaprop+RETalphaprop;
CIWIDTHpropET=UETprop-LETprop;
IF PROPT GT 0 && LETalphaprop LT 0 && RETalphaprop GT 0 THEN empbetapropET=1;
ELSE empbetapropET=0;
POWERpropET=1-empbetapropET;

IMBRpropET=0; IMBLpropET=0;
IF PROPT GT UETprop THEN IMBRpropET=1;
IF PROPT LT LETprop THEN IMBLpropET=1;
IMBALANCEpropET=IMBRpropET-IMBLpropET;

IF PROPT GT LETprop && PROPT LT UETprop THEN COVERAGEpropET=1;
ELSE COVERAGEpropET=0;
COVERAGEpropCHECK=1-IMBRpropET-IMBLpropET;

RHDIalphaprop=0; 
LHDIalphaprop=0;

IF PROPT=0 && LHDIprop GT 0 && UHDIprop GT 0 THEN LHDIalphaprop=1;
IF PROPT=0 && LHDIprop LT 0 && UHDIprop LT 0 THEN RHDIalphaprop=1;

TYPEIERRORpropHDI=LHDIalphaprop+RHDIalphaprop;
CIWIDTHpropHDI=UHDIprop-LHDIprop;
IF PROPT GT 0 && LHDIalphaprop LT 0 && RHDIalphaprop GT 0 THEN empbetapropHDI=1;
ELSE empbetapropHDI=0;
POWERpropHDI=1-empbetapropHDI;

IMBRpropHDI=0; IMBLpropHDI=0;
IF PROPT GT UHDIprop THEN IMBRpropHDI=1;
IF PROPT LT LHDIprop THEN IMBLpropHDI=1;
IMBALANCEpropHDI=IMBRpropHDI-IMBLpropHDI;

IF PROPT GT LHDIprop && PROPT LT UHDIprop THEN COVERAGEpropHDI=1;
ELSE COVERAGEpropHDI=0;
COVERAGEpropHDICHECK=1-IMBRpropHDI-IMBLpropHDI;

*RATIO;
RETalphaRATIO=0; 
LETalphaRATIO=0;


IF RATIOT=0 && LETRATIO GT 0 && UETRATIO GT 0 THEN LETalphaRATIO=1;
IF RATIOT=0 && LETRATIO LT 0 && UETRATIO LT 0 THEN RETalphaRATIO=1;

TYPEIERRORRATIOET=LETalphaRATIO+RETalphaRATIO;
CIWIDTHRATIOET=UETRATIO-LETRATIO;
IF RATIOT GT 0 && LETalphaRATIO LT 0 && RETalphaRATIO GT 0 THEN empbetaRATIOET=1;
ELSE empbetaRATIOET=0;
POWERRATIOET=1-empbetaRATIOET;

IMBRRATIOET=0; IMBLRATIOET=0;
IF RATIOT GT UETRATIO THEN IMBRRATIOET=1;
IF RATIOT LT LETRATIO THEN IMBLRATIOET=1;
IMBALANCERATIOET=IMBRRATIOET-IMBLRATIOET;

IF RATIOT GT LETRATIO && RATIOT LT UETRATIO THEN COVERAGERATIOET=1;
ELSE COVERAGERATIOET=0;
COVERAGERATIOCHECK=1-IMBRRATIOET-IMBLRATIOET;

RHDIalphaRATIO=0; 
LHDIalphaRATIO=0;

IF RATIOT=0 && LHDIRATIO GT 0 && UHDIRATIO GT 0 THEN LHDIalphaRATIO=1;
IF RATIOT=0 && LHDIRATIO LT 0 && UHDIRATIO LT 0 THEN RHDIalphaRATIO=1;

TYPEIERRORRATIOHDI=LHDIalphaRATIO+RHDIalphaRATIO;
CIWIDTHRATIOHDI=UHDIRATIO-LHDIRATIO;
IF RATIOT GT 0 && LHDIalphaRATIO LT 0 && RHDIalphaRATIO GT 0 THEN empbetaRATIOHDI=1;
ELSE empbetaRATIOHDI=0;
POWERRATIOHDI=1-empbetaRATIOHDI;

IMBRRATIOHDI=0; IMBLRATIOHDI=0;
IF RATIOT GT UHDIRATIO THEN IMBRRATIOHDI=1;
IF RATIOT LT LHDIRATIO THEN IMBLRATIOHDI=1;
IMBALANCERATIOHDI=IMBRRATIOHDI-IMBLRATIOHDI;

IF RATIOT GT LHDIRATIO && RATIOT LT UHDIRATIO THEN COVERAGERATIOHDI=1;
ELSE COVERAGERATIOHDI=0;
COVERAGERATIOHDICHECK=1-IMBRRATIOHDI-IMBLRATIOHDI;


*ABPS;
RETalphaABPS=0; 
LETalphaABPS=0;


IF TDMEAS1=0 && LETABPS GT 0 && UETABPS GT 0 THEN LETalphaABPS=1;
IF TDMEAS1=0 && LETABPS LT 0 && UETABPS LT 0 THEN RETalphaABPS=1;

TYPEIERRORABPSET=LETalphaABPS+RETalphaABPS;
CIWIDTHABPSET=UETABPS-LETABPS;
IF TDMEAS1 GT 0 && LETalphaABPS LT 0 && RETalphaABPS GT 0 THEN empbetaABPSET=1;
ELSE empbetaABPSET=0;
POWERABPSET=1-empbetaABPSET;

IMBRABPSET=0; IMBLABPSET=0;
IF TDMEAS1 GT UETABPS THEN IMBRABPSET=1;
IF TDMEAS1 LT LETABPS THEN IMBLABPSET=1;
IMBALANCEABPSET=IMBRABPSET-IMBLABPSET;

IF TDMEAS1 GT LETABPS && TDMEAS1 LT UETABPS THEN COVERAGEABPSET=1;
ELSE COVERAGEABPSET=0;
COVERAGEABPSCHECK=1-IMBRABPSET-IMBLABPSET;

RHDIalphaABPS=0; 
LHDIalphaABPS=0;

IF TDMEAS1=0 && LHDIABPS GT 0 && UHDIABPS GT 0 THEN LHDIalphaABPS=1;
IF TDMEAS1=0 && LHDIABPS LT 0 && UHDIABPS LT 0 THEN RHDIalphaABPS=1;

TYPEIERRORABPSHDI=LHDIalphaABPS+RHDIalphaABPS;
CIWIDTHABPSHDI=UHDIABPS-LHDIABPS;
IF TDMEAS1 GT 0 && LHDIalphaABPS LT 0 && RHDIalphaABPS GT 0 THEN empbetaABPSHDI=1;
ELSE empbetaABPSHDI=0;
POWERABPSHDI=1-empbetaABPSHDI;

IMBRABPSHDI=0; IMBLABPSHDI=0;
IF TDMEAS1 GT UHDIABPS THEN IMBRABPSHDI=1;
IF TDMEAS1 LT LHDIABPS THEN IMBLABPSHDI=1;
IMBALANCEABPSHDI=IMBRABPSHDI-IMBLABPSHDI;

IF TDMEAS1 GT LHDIABPS && TDMEAS1 LT UHDIABPS THEN COVERAGEABPSHDI=1;
ELSE COVERAGEABPSHDI=0;
COVERAGEABPSHDICHECK=1-IMBRABPSHDI-IMBLABPSHDI;

*ABfS;
RETalphaABFS=0; 
LETalphaABFS=0;


IF TDMEAS2=0 && LETABFS GT 0 && UETABFS GT 0 THEN LETalphaABFS=1;
IF TDMEAS2=0 && LETABFS LT 0 && UETABFS LT 0 THEN RETalphaABFS=1;

TYPEIERRORABFSET=LETalphaABFS+RETalphaABFS;
CIWIDTHABFSET=UETABFS-LETABFS;
IF TDMEAS2 GT 0 && LETalphaABFS LT 0 && RETalphaABFS GT 0 THEN empbetaABFSET=1;
ELSE empbetaABFSET=0;
POWERABFSET=1-empbetaABFSET;

IMBRABFSET=0; IMBLABFSET=0;
IF TDMEAS2 GT UETABFS THEN IMBRABFSET=1;
IF TDMEAS2 LT LETABFS THEN IMBLABFSET=1;
IMBALANCEABFSET=IMBRABFSET-IMBLABFSET;

IF TDMEAS2 GT LETABFS && TDMEAS2 LT UETABFS THEN COVERAGEABFSET=1;
ELSE COVERAGEABFSET=0;
COVERAGEABFSCHECK=1-IMBRABFSET-IMBLABFSET;

RHDIalphaABFS=0; 
LHDIalphaABFS=0;

IF TDMEAS2=0 && LHDIABFS GT 0 && UHDIABFS GT 0 THEN LHDIalphaABFS=1;
IF TDMEAS2=0 && LHDIABFS LT 0 && UHDIABFS LT 0 THEN RHDIalphaABFS=1;

TYPEIERRORABFSHDI=LHDIalphaABFS+RHDIalphaABFS;
CIWIDTHABFSHDI=UHDIABFS-LHDIABFS;
IF TDMEAS2 GT 0 && LHDIalphaABFS LT 0 && RHDIalphaABFS GT 0 THEN empbetaABFSHDI=1;
ELSE empbetaABFSHDI=0;
POWERABFSHDI=1-empbetaABFSHDI;

IMBRABFSHDI=0; IMBLABFSHDI=0;
IF TDMEAS2 GT UHDIABFS THEN IMBRABFSHDI=1;
IF TDMEAS2 LT LHDIABFS THEN IMBLABFSHDI=1;
IMBALANCEABFSHDI=IMBRABFSHDI-IMBLABFSHDI;

IF TDMEAS2 GT LHDIABFS && TDMEAS2 LT UHDIABFS THEN COVERAGEABFSHDI=1;
ELSE COVERAGEABFSHDI=0;
COVERAGEABFSHDICHECK=1-IMBRABFSHDI-IMBLABFSHDI;


DATA NEW; SET SUMMARY;
DATA SUMMARY; SET NEW TEST;


PROC MEANS DATA=SUMMARY NOPRINT;
	OUTPUT OUT = &FILE;
%END;

DATA N40.&FILE; 
SET SUMMARY; 
RUN; 
RUN;
%MEND;

%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.39,BYM=.14,    
FILE=z1,TYPE='CCC',ERROR=1, errorm=1,errory=1);

RUN;
quit;

data final;
	set z1
		;
run;

