/***********************************************************************************************************************/
/* This is the code writen for evaluating the bias and efficiency of four effect size measures for the mediated effect */
/* in the single mediator model with continuous X, M, and Y for the manuscript titled                                  */
/* "Statistical Properties of Four Effect Size Measures for Mediation Models".                                         */
/***********************************************************************************************************************/

FILENAME NULLOG DUMMY 'C:\NULL';
PROC PRINTTO LOG=NULLOG;

%MACRO SIMULATE(NSIM,NOBS,BMX,BYM,BYX,FILE,TYPE,ERROR,ERRORM,ERRORY);

DATA SUMMARY; SET _NULL_;
%DO I=1 %TO &NSIM;
TITLE 'SIMULATION OF MEDIATION';
DATA SIM;
DO I=1 TO &NOBS;
X=(&error)*RANNOR(0);
M=&BMX*X+(&errorm)*RANNOR(0);
Y=&BYX*X+&BYM*M+(&errory)*RANNOR(0);
X2=X*X;
OUTPUT;
END;

*This code obtains estimates of the mediation regression
equations for the sample generated in the macro program;

*Estimating the (Y=X) regression and saving the value of bm1 or c in the text;
PROC REG DATA=SIM OUTEST=FILE COVOUT NOPRINT; MODEL Y=X/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; BM1=X;MSE1=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y;
KEEP BM1 MSE1;
DATA C; SET FILE;IF _NAME_='X'; SEBM1=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y;
KEEP SEBM1;
DATA MODEL1; MERGE B C;

RUN;
*Estimating the (Y=X M) regression and saving the values of
c prime and b;
PROC REG DATA=SIM OUTEST=FILE COVOUT NOPRINT;
MODEL Y=X M/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; C=X;
BM2=X; MSE2=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP MSE2 BM2 C;
DATA C; SET FILE;
IF _NAME_='X'; SEBM2=SQRT(X); SEC=SQRT(X);
KEEP SEBM2 SEC;
DATA D; SET FILE; IF _NAME_= 'M'; SEB=SQRT(M);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP SEB;
DATA E; SET FILE; B=M; IF _TYPE_='PARMS';
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP B;
DATA F; SET FILE; IF _NAME_='M'; CBC=X;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M;
KEEP CBC;
DATA MODEL2; MERGE B C D E F;

*Estimating the (M=X) regression and saving the value of a;
PROC REG DATA=SIM OUTEST=FILE COVOUT NOPRINT;
MODEL M=X;
DATA BB; SET FILE;
IF _TYPE_='PARMS'; M=X;
BM2=X; MSE3=_RMSE_*_RMSE_;
KEEP MSE3;

DATA B; SET FILE; A=X; IF _TYPE_='PARMS';
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M;
KEEP A;
DATA C; SET FILE; IF _NAME_='X'; SEA=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M;
KEEP SEA;
DATA MODEL3; MERGE BB B C;

*This code saves the variance of X in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR X;
OUTPUT OUT=OUTA STD=VARX;
DATA VARS; SET OUTA;
VARXX=VARX*VARX;
KEEP VARX VARXX;

*This code saves the variance of M in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR M;
OUTPUT OUT=OUTA STD=VARM;
DATA VARSM; SET OUTA;
VARMM=VARM*VARM;
KEEP VARMM;

*This code saves the variance of Y in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR Y;
OUTPUT OUT=OUTA STD=VARY;
DATA VARSY; SET OUTA;
VARYY=VARY*VARY;
KEEP VARY VARYY;

*This code saves the correlation between X and M in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR; SET COV; IF _NAME_='M'; CORRXM=X;
KEEP CORRXM;
*This code saves the correlation between Y and M in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR1; SET COV; IF _NAME_='Y'; CORRMY=M;
KEEP CORRMY;
*This code saves the correlation between Y and X in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR2; SET COV; IF _NAME_='Y'; CORRXY=X;
KEEP CORRXY;

*This code saves the covariance between X and M in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC1; SET COV; IF _TYPE_='COV';IF _NAME_='M'; COVXM=X;
KEEP COVXM;
*This code saves the covariance between Y and M in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC2; SET COV; IF _TYPE_='COV';IF _NAME_='Y'; COVMY=M;
KEEP COVMY;
*This code saves the covariance between Y and X in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC3; SET COV; IF _TYPE_='COV'; IF _NAME_='Y'; COVXY=X;
KEEP COVXY;

*This code merges the different datasets that contain 
estimates from the simulation replication;

DATA ALL; MERGE MODEL1 MODEL2 MODEL3 VARS VARSM VARSY FR FR1 FR2 FC1 FC2 FC3;
RUN;


*This code calculates the population values for empirical
values estimated in the simulation;
DATA TEST;SET ALL;
TYPE=&TYPE;
ERROR=&ERROR;
DOF=_FREQ_-2;
NOBS=&NOBS;
BMX=&BMX;BYX=&BYX;BYM=&BYM;


*This section computes true variances and covariances based on residual error variance equal to 1;
EMOD1=(&ERROR)**2;
EMOD2=(&ERRORm)**2;
EMOD3=(&ERRORy)**2;
VX1X1=EMOD1; 
CY1X1=BMX*EMOD1;
CY2X1=BYM*BMX*VX1X1+BYX*EMOD1;
CY1Y1=BMX*BMX*VX1X1+EMOD2;
CY2Y1=BMX*BMX*BYM*VX1X1+BMX*BYX*EMOD1+BYM*EMOD2;
CY2Y2=BYM*BYM*(BMX*BMX*EMOD1+EMOD2)+2*BMX*BYM*BYX*VX1X1+BYX*BYX*EMOD1
+EMOD3;
compcp=(cy1y1*cy2x1-cy1x1*cy2y1)/(vx1x1*cy1y1-cy1x1**2);
compb=(vx1x1*cy2y1-Cy1x1*cy2x1)/(vx1x1*cy1y1-cy1x1**2);
;

*The following code computes effect size measures and their biases for the total mediated effect;

*The proportion mediated effect size measure;
AB=A*B;
PROP=AB/(AB+C);
PROPT=BMX*BYM/(BMX*BYM+BYX);
PROPbias=PROP-PROPT;
PROPbiasP=PROPbias/PROPT;

*The ratio of the indirect to the direct effect effect size measure;
RATIO=AB/C;
RATIOT=BMX*BYM/BYX;
RATIObias=RATIO-RATIOT;
RATIObiasP=RATIObias/RATIOT;


/*Standardized Effect Size measures */
DMEAS1=AB/SQRT(VARYY); 

DMEAS2=AB*SQRT(VARXX)/SQRT(VARYY);
TDMEAS1=BMX*BYM/SQRT(CY2Y2); TDMEAS2=BMX*BYM*SQRT(VX1X1)/SQRT(CY2Y2);
BDMEAS1=DMEAS1-TDMEAS1;BDMEAS2=DMEAS2-TDMEAS2;

/*Percent bias for standardized effect size measures */

PBDMEAS1=BDMEAS1/TDMEAS1;
PBDMEAS2=BDMEAS2/TDMEAS2;

DATA NEW; SET SUMMARY;
DATA SUMMARY; SET NEW TEST;


PROC MEANS DATA=SUMMARY NOPRINT;
	OUTPUT OUT = &FILE;
%END;
;
RUN;

%MEND;

%SIMULATE(NSIM=1000,NOBS=1000,BMX=.00,BYX=.00,BYM=.00,    
FILE=z1,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=0,BYM=.14,    
FILE=z2,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=0,BYM=.39,    
FILE=z3,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=0,BYM=.59,    
FILE=z4,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.14,BYM=0,    
FILE=z5,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.14,BYM=.14,    
FILE=z6,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.14,BYM=.39,    
FILE=z7,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.14,BYM=.59,    
FILE=z8,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.39,BYM=0,    
FILE=z9,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.39,BYM=.14,    
FILE=z10,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.39,BYM=.39,    
FILE=z11,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.39,BYM=.59,    
FILE=z12,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.59,BYM=0,    
FILE=z13,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.59,BYM=.14,    
FILE=z14,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.59,BYM=.39,    
FILE=z15,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=0,BYX=.59,BYM=.59,    
FILE=z16,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.0,BYM=.0,    
FILE=z17,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=0,BYM=.14,    
FILE=z18,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=0,BYM=.39,    
FILE=z19,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=0,BYM=.59,    
FILE=z20,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.14,BYM=0,    
FILE=z21,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.14,BYM=.14,    
FILE=z22,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.14,BYM=.39,    
FILE=z23,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.14,BYM=.59,    
FILE=z24,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.39,BYM=0,    
FILE=z25,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.39,BYM=.14,    
FILE=z26,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.39,BYM=.39,    
FILE=z27,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.39,BYM=.59,    
FILE=z28,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.59,BYM=0,    
FILE=z29,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.59,BYM=.14,    
FILE=z30,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.59,BYM=.39,    
FILE=z31,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.14,BYX=.59,BYM=.59,    
FILE=z32,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.0,BYM=.0,    
FILE=z33,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=0,BYM=.14,    
FILE=z34,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=0,BYM=.39,    
FILE=z35,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=0,BYM=.59,    
FILE=z36,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.14,BYM=0,    
FILE=z37,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.14,BYM=.14,    
FILE=z38,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.14,BYM=.39,    
FILE=z39,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.14,BYM=.59,    
FILE=z40,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.39,BYM=0,    
FILE=z41,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.39,BYM=.14,    
FILE=z42,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.39,BYM=.39,    
FILE=z43,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.39,BYM=.59,    
FILE=z44,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.59,BYM=0,    
FILE=z45,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.59,BYM=.14,    
FILE=z46,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.59,BYM=.39,    
FILE=z47,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.39,BYX=.59,BYM=.59,    
FILE=z48,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.0,BYM=.0,    
FILE=z49,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=0,BYM=.14,    
FILE=z50,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=0,BYM=.39,    
FILE=z51,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=0,BYM=.59,    
FILE=z52,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.14,BYM=0,    
FILE=z53,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.14,BYM=.14,    
FILE=z54,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.14,BYM=.39,    
FILE=z55,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.14,BYM=.59,    
FILE=z56,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.39,BYM=0,    
FILE=z57,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.39,BYM=.14,    
FILE=z58,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.39,BYM=.39,    
FILE=z59,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.39,BYM=.59,    
FILE=z60,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.59,BYM=0,    
FILE=z61,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.59,BYM=.14,    
FILE=z62,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.59,BYM=.39,    
FILE=z63,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=1000,BMX=.59,BYX=.59,BYM=.59,    
FILE=z64,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.0,BYM=.0,    
FILE=z65,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=0,BYM=.14,    
FILE=z66,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=0,BYM=.39,    
FILE=z67,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=0,BYM=.59,    
FILE=z68,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.14,BYM=0,    
FILE=z69,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.14,BYM=.14,    
FILE=z70,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.14,BYM=.39,    
FILE=z71,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.14,BYM=.59,    
FILE=z72,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.39,BYM=0,    
FILE=z73,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.39,BYM=.14,    
FILE=z74,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.39,BYM=.39,    
FILE=z75,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.39,BYM=.59,    
FILE=z76,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.59,BYM=0,    
FILE=z77,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.59,BYM=.14,    
FILE=z78,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.59,BYM=.39,    
FILE=z79,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=0,BYX=.59,BYM=.59,    
FILE=z80,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.0,BYM=.0,    
FILE=z81,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=0,BYM=.14,    
FILE=z82,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=0,BYM=.39,    
FILE=z83,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=0,BYM=.59,    
FILE=z84,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.14,BYM=0,    
FILE=z85,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.14,BYM=.14,    
FILE=z86,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.14,BYM=.39,    
FILE=z87,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.14,BYM=.59,    
FILE=z88,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.39,BYM=0,    
FILE=z89,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.39,BYM=.14,    
FILE=z90,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.39,BYM=.39,    
FILE=z91,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.39,BYM=.59,    
FILE=z92,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.59,BYM=0,    
FILE=z93,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.59,BYM=.14,    
FILE=z94,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.59,BYM=.39,    
FILE=z95,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.14,BYX=.59,BYM=.59,    
FILE=z96,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.0,BYM=.0,    
FILE=z97,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=0,BYM=.14,    
FILE=z98,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=0,BYM=.39,    
FILE=z99,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=0,BYM=.59,    
FILE=z100,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.14,BYM=0,    
FILE=z101,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.14,BYM=.14,    
FILE=z102,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.14,BYM=.39,    
FILE=z103,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.14,BYM=.59,    
FILE=z104,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.39,BYM=0,    
FILE=z105,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.39,BYM=.14,    
FILE=z106,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.39,BYM=.39,    
FILE=z107,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.39,BYM=.59,    
FILE=z108,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.59,BYM=0,    
FILE=z109,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.59,BYM=.14,    
FILE=z110,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.59,BYM=.39,    
FILE=z111,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.39,BYX=.59,BYM=.59,    
FILE=z112,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.0,BYM=.0,    
FILE=z113,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=0,BYM=.14,    
FILE=z114,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=0,BYM=.39,    
FILE=z115,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=0,BYM=.59,    
FILE=z116,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.14,BYM=0,    
FILE=z117,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.14,BYM=.14,    
FILE=z118,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.14,BYM=.39,    
FILE=z119,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.14,BYM=.59,    
FILE=z120,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.39,BYM=0,    
FILE=z121,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.39,BYM=.14,    
FILE=z122,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.39,BYM=.39,    
FILE=z123,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.39,BYM=.59,    
FILE=z124,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.59,BYM=0,    
FILE=z125,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.59,BYM=.14,    
FILE=z126,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.59,BYM=.39,    
FILE=z127,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=500,BMX=.59,BYX=.59,BYM=.59,    
FILE=z128,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.0,BYM=.0,    
FILE=z129,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=0,BYM=.14,    
FILE=z130,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=0,BYM=.39,    
FILE=z131,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=0,BYM=.59,    
FILE=z132,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.14,BYM=0,    
FILE=z133,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.14,BYM=.14,    
FILE=z134,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.14,BYM=.39,    
FILE=z135,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.14,BYM=.59,    
FILE=z136,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.39,BYM=0,    
FILE=z137,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.39,BYM=.14,    
FILE=z138,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.39,BYM=.39,    
FILE=z139,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.39,BYM=.59,    
FILE=z140,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.59,BYM=0,    
FILE=z141,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.59,BYM=.14,    
FILE=z142,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.59,BYM=.39,    
FILE=z143,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=0,BYX=.59,BYM=.59,    
FILE=z144,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.0,BYM=.0,    
FILE=z145,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=0,BYM=.14,    
FILE=z146,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=0,BYM=.39,    
FILE=z147,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=0,BYM=.59,    
FILE=z148,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.14,BYM=0,    
FILE=z149,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.14,BYM=.14,    
FILE=z150,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.14,BYM=.39,    
FILE=z151,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.14,BYM=.59,    
FILE=z152,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.39,BYM=0,    
FILE=z153,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.39,BYM=.14,    
FILE=z154,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.39,BYM=.39,    
FILE=z155,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.39,BYM=.59,    
FILE=z156,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.59,BYM=0,    
FILE=z157,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.59,BYM=.14,    
FILE=z158,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.59,BYM=.39,    
FILE=z159,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.14,BYX=.59,BYM=.59,    
FILE=z160,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.0,BYM=.0,    
FILE=z161,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=0,BYM=.14,    
FILE=z162,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=0,BYM=.39,    
FILE=z163,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=0,BYM=.59,    
FILE=z164,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.14,BYM=0,    
FILE=z165,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.14,BYM=.14,    
FILE=z166,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.14,BYM=.39,    
FILE=z167,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.14,BYM=.59,    
FILE=z168,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.39,BYM=0,    
FILE=z169,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.39,BYM=.14,    
FILE=z170,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.39,BYM=.39,    
FILE=z171,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.39,BYM=.59,    
FILE=z172,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.59,BYM=0,    
FILE=z173,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.59,BYM=.14,    
FILE=z174,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.59,BYM=.39,    
FILE=z175,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.39,BYX=.59,BYM=.59,    
FILE=z176,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.0,BYM=.0,    
FILE=z177,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=0,BYM=.14,    
FILE=z178,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=0,BYM=.39,    
FILE=z179,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=0,BYM=.59,    
FILE=z180,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.14,BYM=0,    
FILE=z181,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.14,BYM=.14,    
FILE=z182,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.14,BYM=.39,    
FILE=z183,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.14,BYM=.59,    
FILE=z184,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.39,BYM=0,    
FILE=z185,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.39,BYM=.14,    
FILE=z186,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.39,BYM=.39,    
FILE=z187,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.39,BYM=.59,    
FILE=z188,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.59,BYM=0,    
FILE=z189,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.59,BYM=.14,    
FILE=z190,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.59,BYM=.39,    
FILE=z191,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=100,BMX=.59,BYX=.59,BYM=.59,    
FILE=z192,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.0,BYM=.0,    
FILE=z193,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=0,BYM=.14,    
FILE=z194,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=0,BYM=.39,    
FILE=z195,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=0,BYM=.59,    
FILE=z196,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.14,BYM=0,    
FILE=z197,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.14,BYM=.14,    
FILE=z198,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.14,BYM=.39,    
FILE=z199,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.14,BYM=.59,    
FILE=z200,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.39,BYM=0,    
FILE=z201,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.39,BYM=.14,    
FILE=z202,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.39,BYM=.39,    
FILE=z203,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.39,BYM=.59,    
FILE=z204,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.59,BYM=0,    
FILE=z205,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.59,BYM=.14,    
FILE=z206,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.59,BYM=.39,    
FILE=z207,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=0,BYX=.59,BYM=.59,    
FILE=z208,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.0,BYM=.0,    
FILE=z209,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=0,BYM=.14,    
FILE=z210,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=0,BYM=.39,    
FILE=z211,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=0,BYM=.59,    
FILE=z212,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.14,BYM=0,    
FILE=z213,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.14,BYM=.14,    
FILE=z214,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.14,BYM=.39,    
FILE=z215,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.14,BYM=.59,    
FILE=z216,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.39,BYM=0,    
FILE=z217,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.39,BYM=.14,    
FILE=z218,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.39,BYM=.39,    
FILE=z219,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.39,BYM=.59,    
FILE=z220,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.59,BYM=0,    
FILE=z221,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.59,BYM=.14,    
FILE=z222,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.59,BYM=.39,    
FILE=z223,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.14,BYX=.59,BYM=.59,    
FILE=z224,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.0,BYM=.0,    
FILE=z225,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=0,BYM=.14,    
FILE=z226,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=0,BYM=.39,    
FILE=z227,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=0,BYM=.59,    
FILE=z228,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.14,BYM=0,    
FILE=z229,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.14,BYM=.14,    
FILE=z230,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.14,BYM=.39,    
FILE=z231,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.14,BYM=.59,    
FILE=z232,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.39,BYM=0,    
FILE=z233,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.39,BYM=.14,    
FILE=z234,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.39,BYM=.39,    
FILE=z235,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.39,BYM=.59,    
FILE=z236,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.59,BYM=0,    
FILE=z237,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.59,BYM=.14,    
FILE=z238,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.59,BYM=.39,    
FILE=z239,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.39,BYX=.59,BYM=.59,    
FILE=z240,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.0,BYM=.0,    
FILE=z241,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=0,BYM=.14,    
FILE=z242,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=0,BYM=.39,    
FILE=z243,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=0,BYM=.59,    
FILE=z244,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.14,BYM=0,    
FILE=z245,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.14,BYM=.14,    
FILE=z246,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.14,BYM=.39,    
FILE=z247,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.14,BYM=.59,    
FILE=z248,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.39,BYM=0,    
FILE=z249,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.39,BYM=.14,    
FILE=z250,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.39,BYM=.39,    
FILE=z251,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.39,BYM=.59,    
FILE=z252,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.59,BYM=0,    
FILE=z253,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.59,BYM=.14,    
FILE=z254,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.59,BYM=.39,    
FILE=z255,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=50,BMX=.59,BYX=.59,BYM=.59,    
FILE=z256,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.0,BYM=.0,    
FILE=z257,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=0,BYM=.14,    
FILE=z258,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=0,BYM=.39,    
FILE=z259,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=0,BYM=.59,    
FILE=z260,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.14,BYM=0,    
FILE=z261,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.14,BYM=.14,    
FILE=z262,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.14,BYM=.39,    
FILE=z263,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.14,BYM=.59,    
FILE=z264,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.39,BYM=0,    
FILE=z265,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.39,BYM=.14,    
FILE=z266,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.39,BYM=.39,    
FILE=z267,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.39,BYM=.59,    
FILE=z268,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.59,BYM=0,    
FILE=z269,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.59,BYM=.14,    
FILE=z270,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.59,BYM=.39,    
FILE=z271,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=0,BYX=.59,BYM=.59,    
FILE=z272,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.0,BYM=.0,    
FILE=z273,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=0,BYM=.14,    
FILE=z274,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=0,BYM=.39,    
FILE=z275,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=0,BYM=.59,    
FILE=z276,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.14,BYM=0,    
FILE=z277,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.14,BYM=.14,    
FILE=z278,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.14,BYM=.39,    
FILE=z279,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.14,BYM=.59,    
FILE=z280,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.39,BYM=0,    
FILE=z281,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.39,BYM=.14,    
FILE=z282,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.39,BYM=.39,    
FILE=z283,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.39,BYM=.59,    
FILE=z284,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.59,BYM=0,    
FILE=z285,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.59,BYM=.14,    
FILE=z286,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.59,BYM=.39,    
FILE=z287,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.14,BYX=.59,BYM=.59,    
FILE=z288,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.0,BYM=.0,    
FILE=z289,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=0,BYM=.14,    
FILE=z290,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=0,BYM=.39,    
FILE=z291,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=0,BYM=.59,    
FILE=z292,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.14,BYM=0,    
FILE=z293,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.14,BYM=.14,    
FILE=z294,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.14,BYM=.39,    
FILE=z295,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.14,BYM=.59,    
FILE=z296,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.39,BYM=0,    
FILE=z297,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.39,BYM=.14,    
FILE=z298,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.39,BYM=.39,    
FILE=z299,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.39,BYM=.59,    
FILE=z300,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.59,BYM=0,    
FILE=z301,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.59,BYM=.14,    
FILE=z302,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.59,BYM=.39,    
FILE=z303,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.39,BYX=.59,BYM=.59,    
FILE=z304,TYPE='CCC',ERROR=1, errorm=1,errory=1);

%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.0,BYM=.0,    
FILE=z305,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=0,BYM=.14,    
FILE=z306,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=0,BYM=.39,    
FILE=z307,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=0,BYM=.59,    
FILE=z308,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.14,BYM=0,    
FILE=z309,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.14,BYM=.14,    
FILE=z310,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.14,BYM=.39,    
FILE=z311,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.14,BYM=.59,    
FILE=z312,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.39,BYM=0,    
FILE=z313,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.39,BYM=.14,    
FILE=z314,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.39,BYM=.39,    
FILE=z315,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.39,BYM=.59,    
FILE=z316,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.59,BYM=0,    
FILE=z317,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.59,BYM=.14,    
FILE=z318,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.59,BYM=.39,    
FILE=z319,TYPE='CCC',ERROR=1, errorm=1,errory=1);
%SIMULATE(NSIM=1000,NOBS=10,BMX=.59,BYX=.59,BYM=.59,    
FILE=z320,TYPE='CCC',ERROR=1, errorm=1,errory=1);

RUN;
quit;

data final;
	set z1
		z2
		z3
		z4
		z5
		z6
		z7
		z8
		z9
		z10
		z11
		z12
		z13
		z14
		z15
		z16
		z17
		z18
		z19
		z20
		z21
		z22
		z23
		z24
		z25
		z26
		z27
		z28
		z29
		z30
		z31
		z32
		z33
		z34
		z35
		z36
		z37
		z38
		z39
		z40
		z41
		z42
		z43
		z44
		z45
		z46
		z47
		z48
		z49
		z50
		z51
		z52
		z53
		z54
		z55
		z56
		z57
		z58
		z59
		z60
		z61
		z62
		z63
		z64
		z65
		z66
		z67
		z68
		z69
		z70
		z71
		z72
		z73
		z74
		z75
		z76
		z77
		z78
		z79
		z80
		z81
		z82
		z83
		z84
		z85
		z86
		z87
		z88
		z89
		z90
		z91
		z92
		z93
		z94
		z95
		z96
		z97
		z98
		z99
		z100
		z101
		z102
		z103
		z104
		z105
		z106
		z107
		z108
		z109
		z110
		z111
		z112
		z113
		z114
		z115
		z116
		z117
		z118
		z119
		z120
		z121
		z122
		z123
		z124
		z125
		z126
		z127
		z128
		z129
		z130
		z131
		z132
		z133
		z134
		z135
		z136
		z137
		z138
		z139
		z140
		z141
		z142
		z143
		z144
		z145
		z146
		z147
		z148
		z149
		z150
		z151
		z152
		z153
		z154
		z155
		z156
		z157
		z158
		z159
		z160
		z161
		z162
		z163
		z164
		z165
		z166
		z167
		z168
		z169
		z170
		z171
		z172
		z173
		z174
		z175
		z176
		z177
		z178
		z179
		z180
		z181
		z182
		z183
		z184
		z185
		z186
		z187
		z188
		z189
		z190
		z191
		z192
		z193
		z194
		z195
		z196
		z197
		z198
		z199
		z200
		z201
		z202
		z203
		z204
		z205
		z206
		z207
		z208
		z209
		z210
		z211
		z212
		z213
		z214
		z215
		z216
		z217
		z218
		z219
		z220
		z221
		z222
		z223
		z224
		z225
		z226
		z227
		z228
		z229
		z230
		z231
		z232
		z233
		z234
		z235
		z236
		z237
		z238
		z239
		z240
		z241
		z242
		z243
		z244
		z245
		z246
		z247
		z248
		z249
		z250
		z251
		z252
		z253
		z254
		z255
		z256
		z257
		z258
		z259
		z260
		z261
		z262
		z263
		z264
		z265
		z266
		z267
		z268
		z269
		z270
		z271
		z272
		z273
		z274
		z275
		z276
		z277
		z278
		z279
		z280
		z281
		z282
		z283
		z284
		z285
		z286
		z287
		z288
		z289
		z290
		z291
		z292
		z293
		z294
		z295
		z296
		z297
		z298
		z299
		z300
		z301
		z302
		z303
		z304
		z305
		z306
		z307
		z308
		z309
		z310
		z311
		z312
		z313
		z314
		z315
		z316
		z317
		z318
		z319
		z320

		;
run;



