/***********************************************************************************************************************/
/* This is the code writen for evaluating the bias and efficiency of four effect size measures for the mediated effect */
/* in a two mediator model with binary X and continuous M1, M2, and Y for the manuscript titled                        */
/* "Statistical Properties of Four Effect Size Measures for Mediation Models".                                         */
/***********************************************************************************************************************/

FILENAME NULLOG DUMMY 'C:\NULL';
PROC PRINTTO LOG=NULLOG;

%MACRO SIMULATE(NSIM,NOBS,A1,A2,B1,B2,CP,FILE,TYPE,ERROR,ERRORM1,ERRORM2,ERRORY);

DATA SUMMARY; SET _NULL_;
%DO I=1 %TO &NSIM;
TITLE 'SIMULATION OF MEDIATION';
DATA SIM;
DO I=1 TO &NOBS;
Z=(&ERROR)*RANNOR(0);
IF Z LT 0 THEN X=0;
IF Z GT 0 THEN X=1;
M1=&A1*X+(&ERRORM1)*RANNOR(0);
M2=&A2*X+(&ERRORM2)*RANNOR(0);
Y=&CP*X+&B1*M1+&B2*M2+(&ERRORY)*RANNOR(0);
X2=X*X;
OUTPUT;
END;

*This code obtains estimates of the mediation regression
equations for the sample generated in the macro program;

*Estimating the (Y=X) regression and saving the value of "BC" or c in the text;
PROC REG DATA=SIM OUTEST=FILE COVOUT noprint; MODEL Y=X/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; BC=X; MSE1=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y;
KEEP BC MSE1;
DATA C; SET FILE; IF _NAME_='X'; SEBC=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y;
KEEP SEBC;
DATA MODEL1; MERGE B C;

*Estimating the (M1=X) regression and saving the value of "BA1" or a1 in the text;
PROC REG DATA=SIM OUTEST=FILE COVOUT noprint; MODEL M1=X/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; BA1=X; MSE3=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M1;
KEEP BA1 MSE3;
DATA C; SET FILE; IF _NAME_='X'; SEBA1=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M1;
KEEP SEBA1;
DATA MODEL2; MERGE B C;

*Estimating the (M2=X) regression and saving the value of "BA2" or a2 in the text;
PROC REG DATA=SIM OUTEST=FILE COVOUT noprint; MODEL M2=X/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; BA2=X; MSE4=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M2;
KEEP BA2 MSE4;
DATA C; SET FILE; IF _NAME_='X'; SEBA2=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X M2;
KEEP SEBA2;
DATA MODEL3; MERGE B C;

*Estimating the (Y=X M1 M2) regression and saving the values of
c prime, b1, and b2;
PROC REG DATA=SIM OUTEST=FILE COVOUT NOPRINT;
MODEL Y=X M1 M2/;
DATA B; SET FILE;
IF _TYPE_='PARMS'; BCP=X; BB1=M1; BB2=M2; MSE2=_RMSE_*_RMSE_;
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M1 M2;
KEEP BCP BB1 BB2 MSE2;
DATA C; SET FILE; IF _NAME_='X'; SEBCP=SQRT(X);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M1 M2;
KEEP SEBCP;
DATA D; SET FILE; IF _NAME_= 'M1'; SEBB1=SQRT(M1);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M1 M2;
KEEP SEBB1;
DATA E; SET FILE; IF _NAME_= 'M2'; SEBB2=SQRT(M2);
DROP _MODEL_ _NAME_ _TYPE_ _DEPVAR_ _RMSE_ INTERCEP X Y M1 M2;
KEEP SEBB2;
DATA MODEL4; MERGE B C D E;

*This code saves the variance of X in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR X;
OUTPUT OUT=OUTA STD=VARX;
DATA VARS; SET OUTA;
VARXX=VARX*VARX;
KEEP VARX VARXX;

*This code saves the variance of M1 in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR M1;
OUTPUT OUT=OUTA STD=VARM1;
DATA VARSM1; SET OUTA;
VARM1M1=VARM1*VARM1;
KEEP VARM1M1;

*This code saves the variance of M2 in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR M2;
OUTPUT OUT=OUTA STD=VARM2;
DATA VARSM2; SET OUTA;
VARM2M2=VARM2*VARM2;
KEEP VARM2M2;

*This code saves the variance of Y in the sample;
PROC MEANS DATA=SIM STD NOPRINT; VAR Y;
OUTPUT OUT=OUTA STD=VARY;
DATA VARSY; SET OUTA;
VARYY=VARY*VARY;
KEEP VARY VARYY;

*This code saves the correlation between X and M1 in the sample;
PROC CORR DATA=SIM OUTP=COV NOPRINT;
DATA FR; SET COV; IF _NAME_='M1'; CORRXM1=X;
KEEP CORRXM1;

*This code saves the correlation between X and M2 in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR1; SET COV; IF _NAME_='M2'; CORRXM2=X;
KEEP CORRXM2;

*This code saves the correlation between Y and M1 in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR2; SET COV; IF _NAME_='Y'; CORRM1Y=M1;
KEEP CORRM1Y;

*This code saves the correlation between Y and M2 in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR3; SET COV; IF _NAME_='Y'; CORRM2Y=M2;
KEEP CORRM2Y;

*This code saves the correlation between Y and X in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR4; SET COV; IF _NAME_='Y'; CORRXY=X;
KEEP CORRXY;

*This code saves the correlation between M1 and M2 in the sample;
PROC CORR DATA=SIM OUTPUT=COV NOPRINT;
DATA FR5; SET COV; IF _NAME_='M2'; CORRM1M2=M1;
KEEP CORRM1M2;

*This code saves the covariance between X and M1 in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC1; SET COV; IF _TYPE_='COV'; IF _NAME_='M1'; COVXM1=X;
KEEP COVXM1;

*This code saves the covariance between X and M2 in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC2; SET COV; IF _TYPE_='COV'; IF _NAME_='M2'; COVXM2=X;
KEEP COVXM2;

*This code saves the covariance between Y and M1 in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC3; SET COV; IF _TYPE_='COV'; IF _NAME_='Y'; COVM1Y=M1;
KEEP COVM1Y;

*This code saves the covariance between Y and M2 in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC4; SET COV; IF _TYPE_='COV'; IF _NAME_='Y'; COVM2Y=M2;
KEEP COVM2Y;

*This code saves the covariance between Y and X in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC5; SET COV; IF _TYPE_='COV'; IF _NAME_='Y'; COVXY=X;
KEEP COVXY;

*This code saves the covariance between M1 and M2 in the sample;
PROC CORR COV DATA=SIM OUTPUT=COV NOPRINT;
DATA FC6; SET COV; IF _TYPE_='COV'; IF _NAME_='M2'; COVM1M2=M1;
KEEP COVM1M2;

*This code merges the different datasets that contain 
estimates from the simulation replication;

DATA ALL; MERGE SIM MODEL1 MODEL2 MODEL3 MODEL4 VARS VARSM1 VARSM2 VARSY FR FR1 FR2 FR3 FR4 FR5 FC1 FC2 FC3 FC4 FC5 FC6;
RUN;

*This code calculates the population values for empirical
values estimated in the simulation;
DATA TEST; SET ALL;
TYPE=&TYPE;
ERROR=&ERROR;
DOF=_FREQ_-2;
NOBS=&NOBS;
A1=&A1; B1=&B1; A2=&A2; B2=&B2; CP=&CP;

*This section computes true variances and covariances as in Section 4.10 based
on residual error variance equal to 1;
EMOD1=0.25;
EMOD2=(&ERRORM1)**2;
EMOD3=(&ERRORM2)**2;
EMOD4=(&ERRORY)**2;
CXX=EMOD1;
CM1X=A1*EMOD1;
CM2X=A2*EMOD1;
CYX=CP*EMOD1+A1*B1*EMOD1+A2*B2*EMOD1;
CM1M1=A1*A1*EMOD1+EMOD2;
CM1M2=A1*A2*EMOD1;
CM1Y=A1*CP*EMOD1+A1*A1*B1*EMOD1+A1*A2*B2*EMOD1+B1*EMOD2;
CM2M2=A2*A2*EMOD1+EMOD3;
CM2Y=A2*CP*EMOD1+A1*A2*B1*EMOD1+A2*A2*B2*EMOD1+B2*EMOD3;
CYY=(CP*CP*EMOD1)+(2*A1*B1*CP*EMOD1)+(2*A2*B2*CP*EMOD1)+(2*A1*A2*B1*B2*EMOD1)+(B1*B1*(A1*A1*EMOD1+EMOD2))+(B2*B2*(A2*A2*EMOD1+EMOD3))+EMOD4;
STDY=SQRT(CYY);
STDX=SQRT(CXX);

*The following code computes effect size measures and their biases for the total mediated effect;

*The true and sample partially standardized indirect effect size measures;
PARTSD=(BA1*BB1+BA2*BB2)/VARY;
PARTSDT=(A1*B1+A2*B2)/STDY;

*Bias and relative bias for the partially standardized indirect effect size measures;
PARTSDBIAS=PARTSD-PARTSDT;
PARTSDRELBIAS=PARTSDBIAS/PARTSDT;

*The true and sample fully standardized indirect effect size measures;
FULLSD=((BA1*BB1+BA2*BB2)*VARX)/VARY;
FULLSDT=((A1*B1+A2*B2)*STDX)/STDY;

*Bias and relative bias for the fully standardized indirect effect size measures;
FULLSDBIAS=FULLSD-FULLSDT;
FULLSDRELBIAS=FULLSDBIAS/FULLSDT;

*The true and sample proportion mediated effect size measures;
PROP=(BA1*BB1+BA2*BB2)/(BA1*BB1+BA2*BB2+BCP);
PROPT=(A1*B1+A2*B2)/(A1*B1+A2*B2+CP);

*Bias and relative bias for the proportion mediated effect size measure;
PROPBIAS=PROP-PROPT;
PROPRELBIAS=PROPBIAS/PROPT;

*The true and sample ratio of the indirect to the direct effect effect size measures;
RATIO=(BA1*BB1+BA2*BB2)/BCP;
RATIOT=(A1*B1+A2*B2)/CP;

*Bias and relative bias for the ratio effect size measure;
RATIOBIAS=RATIO-RATIOT;
RATIORELBIAS=RATIOBIAS/RATIOT;

DATA NEW; SET SUMMARY;
DATA SUMMARY; SET NEW TEST;
%END;

PROC MEANS DATA=SUMMARY;
	OUTPUT OUT = &FILE;

;
RUN;
%MEND;

%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0,B2=0,CP=0,
FILE=Z1,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.101,B2=0.101,CP=0,
FILE=Z2,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.314,B2=0.314,CP=0,
FILE=Z3,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.577,B2=0.577,CP=0,
FILE=Z4,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0,B2=0,CP=0.131,
FILE=Z5,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.101,B2=0.101,CP=0.131,
FILE=Z6,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.314,B2=0.314,CP=0.131,
FILE=Z7,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.577,B2=0.577,CP=00.131,
FILE=Z8,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0,B2=0,CP=0.4,
FILE=Z9,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.101,B2=0.101,CP=0.4,
FILE=Z10,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.314,B2=0.314,CP=0.4,
FILE=Z11,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.577,B2=0.577,CP=0.4,
FILE=Z12,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0,B2=0,CP=0.74,
FILE=Z13,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.101,B2=0.101,CP=0.74,
FILE=Z14,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.314,B2=0.314,CP=0.74,
FILE=Z15,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0,B1=0,A2=0.577,B2=0.577,CP=0.74,
FILE=Z16,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0,B2=0,CP=0,
FILE=Z17,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0,
FILE=Z18,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0,
FILE=Z19,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=0,
FILE=Z20,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0,B2=0,CP=0.131,
FILE=Z21,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0.131,
FILE=Z22,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0.131,
FILE=Z23,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=00.131,
FILE=Z24,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0,B2=0,CP=0.4,
FILE=Z25,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0.4,
FILE=Z26,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0.4,
FILE=Z27,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=0.4,
FILE=Z28,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0,B2=0,CP=0.74,
FILE=Z29,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0.74,
FILE=Z30,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0.74,
FILE=Z31,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=0.74,
FILE=Z32,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0,B2=0,CP=0,
FILE=Z33,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0,
FILE=Z34,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0,
FILE=Z35,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=0,
FILE=Z36,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0,B2=0,CP=0.131,
FILE=Z37,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0.131,
FILE=Z38,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0.131,
FILE=Z39,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=00.131,
FILE=Z40,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0,B2=0,CP=0.4,
FILE=Z41,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0.4,
FILE=Z42,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0.4,
FILE=Z43,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=0.4,
FILE=Z44,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0,B2=0,CP=0.74,
FILE=Z45,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0.74,
FILE=Z46,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0.74,
FILE=Z47,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=0.74,
FILE=Z48,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0,B2=0,CP=0,
FILE=Z49,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0,
FILE=Z50,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0,
FILE=Z51,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=0,
FILE=Z52,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0,B2=0,CP=0.131,
FILE=Z53,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0.131,
FILE=Z54,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0.131,
FILE=Z55,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=00.131,
FILE=Z56,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0,B2=0,CP=0.4,
FILE=Z57,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0.4,
FILE=Z58,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0.4,
FILE=Z59,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=0.4,
FILE=Z60,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0,B2=0,CP=0.74,
FILE=Z61,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0.74,
FILE=Z62,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0.74,
FILE=Z63,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);
%SIMULATE(NSIM=1000,NOBS=500,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=0.74,
FILE=Z64,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1);


RUN;
quit;

data final;
	set z1
		z2
		z3
		z4
		z5
		z6
		z7
		z8
		z9
		z10
		z11
		z12
		z13
		z14
		z15
		z16
		z17
		z18
		z19
		z20
		z21
		z22
		z23
		z24
		z25
		z26
		z27
		z28
		z29
		z30
		z31
		z32
		z33
		z34
		z35
		z36
		z37
		z38
		z39
		z40
		z41
		z42
		z43
		z44
		z45
		z46
		z47
		z48
		z49
		z50
		z51
		z52
		z53
		z54
		z55
		z56
		z57
		z58
		z59
		z60
		z61
		z62
		z63
		z64
		;
run;
