/***********************************************************************************************************************/
/* This is the code writen for evaluating the statistical properties of bootstrap interval estimates of four           */
/* effect size measures for the mediated effect in a two mediator model with continuous X, M1, M2, and Y               */
/* for the manuscript titled "Statistical Properties of Four Effect Size Measures for Mediation Models".               */
/***********************************************************************************************************************/

FILENAME NULLOG DUMMY 'C:\NULL';
proc printto log=nullog;

%MACRO SIMULATE(NSIM,NOBS,A1,A2,B1,B2,CP,FILE,TYPE,ERROR,ERRORM1,ERRORM2,ERRORY,NBOOT);

DATA SUMMARY; SET _NULL_;
%DO I=1 %TO &NSIM;
DATA SIM;
DO I=1 TO &NOBS;
X=(&ERROR)*RANNOR(0);
M1=&A1*X+(&ERRORM1)*RANNOR(0);
M2=&A2*X+(&ERRORM2)*RANNOR(0);
Y=&CP*X+&B1*M1+&B2*M2+(&ERRORY)*RANNOR(0);
X2=X*X;
%LET CC=(&A1*&B1)+(&A2*&B2)+&CP;
OUTPUT;
END;

proc reg data=sim outest=outa covout noprint;
model y = m1 m2 x;
model m1 = x;
model m2 = x;
model y = x;
run;
quit;

data outac;
set outa;
if _TYPE_^='PARMS' then delete;
if _MODEL_='MODEL1' then call symput ("bb1", m1);
if _MODEL_='MODEL1' then call symput ("bb2", m2);
if _MODEL_='MODEL1' then call symput ("ccp", x);
if _MODEL_='MODEL2' then call symput ("aa1", x);
if _MODEL_='MODEL3' then call symput ("aa2", x);
if _MODEL_='MODEL4' then call symput ("ccc", x);

proc corr cov data=sim outp=outb noprint;
run;
quit;

data outb;
set outb;
if _TYPE_^='COV' then delete;

data outb;
set outb;
if _NAME_='X' then call symput ("svarx", x);
if _NAME_='Y' then call symput ("svary", y);

/*Bootstrap*/
*This is where the bootstrap samples are made;
*sampsize should be equal to the number of observations in the dataset;
*rep is the number of bootstrap samples you want;

proc surveyselect data=sim noprint out=out2 method=urs sampsize=&NOBS rep=&nboot outhits;
run;
quit;

proc reg data=OUT2 outest=out3 tableout covout noprint;
by Replicate;
model y = m1 m2 x;
model m1 = x;
model m2 = x;
model y = x;

data parm; set out3;
if _TYPE_^='PARMS' then delete;

data se; set out3;
if _TYPE_^='STDERR' then delete;

data p; set out3;
if _TYPE_^='PVALUE' then delete;

data cov; set out3;
if _TYPE_^='COV' then delete;
if _NAME_^='M2' then delete;

data b1; set parm;
if _MODEL_^='MODEL1' then delete;
rb1=m1;
keep Replicate rb1;

data b1se; set se;
if _MODEL_^='MODEL1' then delete;
rb1se=m1;
keep Replicate rb1se;

data b2; set parm;
if _MODEL_^='MODEL1' then delete;
rb2=m2;
keep Replicate rb2;

data b2se; set se;
if _MODEL_^='MODEL1' then delete;
rb2se=m2;
keep Replicate rb2se;

data covb1b2; set cov;
if _MODEL_^='MODEL1' then delete;
rcovb1b2=m1;
keep Replicate rcovb1b2;

data a1; set parm;
if _MODEL_^='MODEL2' then delete;
ra1=x;
keep Replicate ra1;

data a1se; set se;
if _MODEL_^='MODEL2' then delete;
ra1se=x;
keep Replicate ra1se;

data a2; set parm;
if _MODEL_^='MODEL3' then delete;
ra2=x;
keep Replicate ra2;

data a2se; set se;
if _MODEL_^='MODEL3' then delete;
ra2se=x;
keep Replicate ra2se;

data c; set parm;
if _MODEL_^='MODEL4' then delete;
rc=x;
keep Replicate rc;

data cse; set se;
if _MODEL_^='MODEL4' then delete;
rcse=x;
keep Replicate rcse;

data cpval; set parm;
if _MODEL_^='MODEL1' then delete;
rcpval=x;
keep Replicate rcpval;

PROC MEANS DATA=out2 NOPRINT;
by Replicate;
VAR X Y;
OUTPUT OUT=STD stddev(X)=rsX stddev(Y)=rsY;
keep Replicate rsX rsY;

data trueSD; set out2;
EMOD1=(&ERROR)**2;
EMOD2=(&ERRORm1)**2;
EMOD3=(&ERRORm2)**2;
EMOD4=(&ERRORy)**2;
truevarx=EMOD1; 
truevarm1=&a1**2*EMOD1+EMOD2;
truevarm2=&a2**2*EMOD1+EMOD3;
truecovxm1=&a1*EMOD1;
truecovxm2=&a2*EMOD1;
truecovm1m2=&a1*&a2*EMOD1;
truevary=&b1**2*truevarm1+2*&b1*&b2*truecovm1m2+2*&b1*&cp*truecovxm1+&b2**2*truevarm2+2*&b2*&cp*truecovxm2+&cp**2*EMOD1+EMOD4;

proc means data=truesd noprint;
by replicate;
output out=truestd mean(truevarx)=truevarx mean(truevarm1)=truevarm1 mean(truevarm2)=truevarm2 mean(truecovxm1)=truecovxm1 
mean(truecovxm2)=truecovxm2 mean(truecovm1m2)=truecovm1m2 mean(truevary)=truevary;

data d; merge b1 b1se b2 b2se covb1b2 a1 a1se a2 a2se c cse cpval STD truestd; by Replicate;

a1b1=ra1*rb1;
a2b2=ra2*rb2;
med=a1b1+a2b2;
PSTD=med/rsY;
FSTD=med*rsX/rsY;
PROP=(a1b1+a2b2)/(a1b1+a2b2+rcpval);
RATIO=(a1b1+a2b2)/rcpval;
if PSTD<=((&aa1*&bb1)+(&aa2*&bb2))/sqrt(&svary) then zPSTD=1; else zPSTD=0;
if FSTD<=((&aa1*&bb1)+(&aa2*&bb2))*sqrt(&svarx)/sqrt(&svary) then zFSTD=1; else zFSTD=0;
if PROP<=((&aa1*&bb1)+(&aa2*&bb2))/&ccc then zPROP=1; else zPROP=0;
if RATIO<=((&aa1*&bb1)+(&aa2*&bb2))/&ccp then zRATIO=1; else zRATIO=0;

proc means data=d noprint;
var zPSTD zFSTD zPROP zRATIO;
output out=out4 mean(zPSTD)=mzpstd mean(zFSTD)=mzfstd mean(zPROP)=mzprop
mean(zRATIO)=mzratio;

data out4; set out4;
call symput("mzpstd", mzpstd);
call symput("mzfstd", mzfstd);
call symput("mzprop", mzprop);
call symput("mzratio", mzratio);

proc sort data=d;
by PSTD;
run;

data e; set d;
z0p=probit(&mzpstd);
if _N_=(ceil(.025*&nboot)) then call symput("lpstd", PSTD);
if _N_=(ceil(.975*&nboot)) then call symput("upstd", PSTD);
if _N_=(ceil(&nboot*probnorm((2*z0p)+probit(.025)))) then call symput("BClpstd", PSTD);
if _N_=(ceil(&nboot*probnorm((2*z0p)+probit(.975)))) then call symput("BCupstd", PSTD);
run;
quit;

proc sort data=d;
by FSTD;
run;

data g; set d;
z0f=probit(&mzfstd);
if _N_=(ceil(.025*&nboot)) then call symput("lfstd",FSTD);
if _N_=(ceil(.975*&nboot)) then call symput("ufstd", FSTD);
if _N_=(ceil(&nboot*probnorm((2*z0f)+probit(.025)))) then call symput("BClfstd", FSTD);
if _N_=(ceil(&nboot*probnorm((2*z0f)+probit(.975)))) then call symput("BCufstd", FSTD);
run;
quit;

proc sort data=d;
by PROP;
run;

data H; set d;

z0pr=probit(&mzprop);
if _N_=(ceil(.025*&nboot)) then call symput("lprop",PROP);
if _N_=(ceil(.975*&nboot)) then call symput("uprop", PROP);
if _N_=(ceil(&nboot*probnorm((2*z0pr)+probit(.025)))) then call symput("BClprop", PROP);
if _N_=(ceil(&nboot*probnorm((2*z0pr)+probit(.975)))) then call symput("BCuprop", PROP);
run;
quit;

proc sort data=d;
by RATIO;
run;

data I; set d;
z0r=probit(&mzratio);
if _N_=(ceil(.025*&nboot)) then call symput("lratio",RATIO);
if _N_=(ceil(.975*&nboot)) then call symput("uratio", RATIO);
if _N_=(ceil(&nboot*probnorm((2*z0r)+probit(.025)))) then call symput("BClratio", RATIO);
if _N_=(ceil(&nboot*probnorm((2*z0r)+probit(.975)))) then call symput("BCuratio", RATIO);
run;
quit;

data f; merge e g h i;

lpstd=&lpstd;
upstd=&upstd;
BClpstd=&BClpstd;
BCupstd=&BCupstd;
lfstd=&lfstd;
ufstd=&ufstd;
BClfstd=&BClfstd;
BCufstd=&BCufstd;
lprop=&lprop;
uprop=&uprop;
BClprop=&BClprop;
BCuprop=&BCuprop;
lratio=&lratio;
uratio=&uratio;
BClratio=&BClratio;
BCuratio=&BCuratio;

/*QUANTITIES OF INTEREST*/
*Coverage, power, imbalance, Type I errorrate, and interval width;

/*PSTD*/
/*Percentile bootstrap*/

data perc; set f;
RGBOOT1=0; LFBOOT1=0;
PSTD1=((&a1*&b1)+(&a2*&b2));
PSTD2=sqrt(truevary);
PSTD3=PSTD1/PSTD2;
IF PSTD3  GT upstd THEN RGBOOT1=1;
IF PSTD3  LT lpstd THEN LFBOOT1=1;

TYPEIERRORRATEBOOTR1=0;
TYPEIERRORRATEBOOTL1=0;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary)=0 && lpstd GT 0 && upstd GT 0 then TYPEIERRORRATEBOOTL1=1;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary)=0 && lpstd LT 0 && upstd LT 0 then TYPEIERRORRATEBOOTR1=1;
TYPEIERRORRATEBOOT1=TYPEIERRORRATEBOOTR1+TYPEIERRORRATEBOOTL1;
IMBALANCEBOOT1=RGBOOT1-LFBOOT1;

CIWIDTHBOOT1=upstd-lpstd;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) GT 0 && lpstd LT 0 && upstd GT 0 THEN empbetaB1=1;
ELSE empbetaB1=0;
POWERBOOT1=1-empbetaB1;

IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) GT lpstd && ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) LT upstd THEN COVERAGEBOOT1=1;
ELSE COVERAGEBOOT1=0;
/*BC bootstrap */
RGBCBOOT1=0; LFBCBOOT1=0;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) GT BCupstd THEN RGBCBOOT1=1;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) LT BClpstd THEN LFBCBOOT1=1;

TYPEIERRORRATEBCBOOTR1=0;
TYPEIERRORRATEBCBOOTL1=0;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary)=0 && BClpstd GT 0 && BCupstd GT 0 then TYPEIERRORRATEBCBOOTL1=1;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary)=0 && BClpstd LT 0 && BCupstd LT 0 then TYPEIERRORRATEBCBOOTR1=1;
TYPEIERRORRATEBC1=TYPEIERRORRATEBCBOOTR1+TYPEIERRORRATEBCBOOTL1;
IMBALANCEBC1=RGBCBOOT1-LFBCBOOT1;

CIWIDTHBC1=BCupstd-BClpstd;
IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) GT 0 && BClpstd LT 0 && BCupstd GT 0 THEN empbetaBC1=1;
ELSE empbetaBC1=0;
POWERBC1=1-empbetaBC1;

IF ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) GT BClpstd && ((&a1*&b1)+(&a2*&b2))/sqrt(truevary) LT BCupstd THEN COVERAGEBC1=1;
ELSE COVERAGEBC1=0;

data perc;
set perc;
keep Replicate rgboot1 lfboot1 PSTD1 PSTD2 PSTD3 TYPEIERRORRATEBOOT1 CIWIDTHBOOT1 empbetaB1 POWERBOOT1 IMBALANCEBOOT1 COVERAGEBOOT1 RGBCBOOT1 LFBCBOOT1 TYPEIERRORRATEBC1
CIWIDTHBC1 empbetaBC1 POWERBC1 IMBALANCEBC1 COVERAGEBC1;


/*FSTD*/
/*Percentile bootstrap*/
data perc2; set f;
RGBOOT2=0; LFBOOT2=0;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary)  GT ufstd THEN RGBOOT2=1;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary)  LT lfstd THEN LFBOOT2=1;

TYPEIERRORRATEBOOTR2=0;
TYPEIERRORRATEBOOTL2=0;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary)=0 && lfstd GT 0 && ufstd GT 0 then TYPEIERRORRATEBOOTL2=1;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary)=0 && lfstd LT 0 && ufstd LT 0 then TYPEIERRORRATEBOOTR2=1;
TYPEIERRORRATEBOOT2=TYPEIERRORRATEBOOTR2+TYPEIERRORRATEBOOTL2;
IMBALANCEBOOT2=RGBOOT2-LFBOOT2;

CIWIDTHBOOT2=ufstd-lfstd;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) GT 0 && lfstd LT 0 && ufstd GT 0 THEN empbetaB2=1;
ELSE empbetaB2=0;
POWERBOOT2=1-empbetaB2;

IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) GT lfstd && ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) LT ufstd THEN COVERAGEBOOT2=1;
ELSE COVERAGEBOOT2=0;

/*BC bootstrap */
RGBCBOOT2=0; LFBCBOOT2=0;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) GT BCufstd THEN RGBCBOOT2=1;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) LT BClfstd THEN LFBCBOOT2=1;

TYPEIERRORRATEbcBOOTR2=0;
TYPEIERRORRATEbcBOOTL2=0;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary)=0 && BClfstd GT 0 && BCufstd GT 0 then TYPEIERRORRATEbcBOOTL2=1;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary)=0 && BClfstd LT 0 && BCufstd LT 0 then TYPEIERRORRATEbcBOOTR2=1;
TYPEIERRORRATEBC2=TYPEIERRORRATEbcBOOTR2+TYPEIERRORRATEbcBOOTL2;
IMBALANCEBC2=RGBCBOOT2-LFBCBOOT2;

CIWIDTHBC2=BCufstd-BClfstd;
IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) GT 0 && BClfstd LT 0 && BCufstd GT 0 THEN empbetaBC2=1;
ELSE empbetaBC2=0;
POWERBC2=1-empbetaBC2;

IF ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) GT BClfstd && ((&a1*&b1)+(&a2*&b2))*sqrt(truevarx)/sqrt(truevary) LT BCufstd THEN COVERAGEBC2=1;
ELSE COVERAGEBC2=0;

data perc2;
set perc2;
keep Replicate rgboot2 lfboot2 TYPEIERRORRATEBOOT2 CIWIDTHBOOT2 empbetaB2 POWERBOOT2 IMBALANCEBOOT2 COVERAGEBOOT2 RGBCBOOT2 LFBCBOOT2 TYPEIERRORRATEBC2
CIWIDTHBC2 empbetaBC2 POWERBC2 IMBALANCEBC2 COVERAGEBC2;


/*proportion mediated*/
/*Percentile bootstrap*/

data perc3; set f;
RGBOOT3=0; LFBOOT3=0;
PROP1=((&a1*&b1)+(&a2*&b2));
PROP2=&CC;
PROP3=PROP1/PROP2;

IF PROP3  GT uprop THEN RGBOOT3=1;
IF PROP3  LT lprop THEN LFBOOT3=1;


TYPEIERRORRATEBOOTR3=0;
TYPEIERRORRATEBOOTL3=0;

IF PROP3=0 && lprop GT 0 && uprop GT 0 then TYPEIERRORRATEBOOTL3=1;
IF PROP3=0 && lprop LT 0 && uprop LT 0 then TYPEIERRORRATEBOOTR3=1;
TYPEIERRORRATEBOOT3=TYPEIERRORRATEBOOTR3+TYPEIERRORRATEBOOTL3;
IMBALANCEBOOT3=RGBOOT3-LFBOOT3;


CIWIDTHBOOT3=uprop-lprop;
IF PROP3 GT 0 && lprop LT 0 && uprop GT 0 THEN empbetaB3=1;
ELSE empbetaB3=0;
POWERBOOT3=1-empbetaB3;

IF PROP3 GT lprop && PROP3 LT uprop THEN COVERAGEBOOT3=1;
ELSE COVERAGEBOOT3=0;

/*BC bootstrap */
RGBCBOOT3=0; LFBCBOOT3=0;
BCPROP1=((&a1*&b1)+(&a2*&b2));
BCPROP2=&CC;
BCPROP3=BCPROP1/BCPROP2;

IF BCPROP3 GT BCuprop THEN RGBCBOOT3=1;
IF BCPROP3 LT BClprop THEN LFBCBOOT3=1;


TYPEIERRORRATEbcBOOTR3=0;
TYPEIERRORRATEbcBOOTL3=0;

IF BCPROP3=0 && BClprop GT 0 && BCuprop GT 0 then TYPEIERRORRATEbcBOOTL3=1;
IF BCPROP3=0 && BClprop LT 0 && BCuprop LT 0 then TYPEIERRORRATEbcBOOTR3=1;
TYPEIERRORRATEBC3=TYPEIERRORRATEbcBOOTR3+TYPEIERRORRATEbcBOOTL3;
IMBALANCEBC3=RGBCBOOT3-LFBCBOOT3;


CIWIDTHBC3=BCuprop-BClprop;
IF BCPROP3 GT 0 && BClprop LT 0 && BCuprop GT 0 THEN empbetaBC3=1;
ELSE empbetaBC3=0;
POWERBC3=1-empbetaBC3;

IF BCPROP3 GT BClprop && BCPROP3 LT BCuprop THEN COVERAGEBC3=1;
ELSE COVERAGEBC3=0;

data perc3;
set perc3;
keep Replicate rgboot3 lfboot3 PROP1 PROP2 PROP3 TYPEIERRORRATEBOOT3 CIWIDTHBOOT3 empbetaB3 POWERBOOT3 IMBALANCEBOOT3 COVERAGEBOOT3 RGBCBOOT3 LFBCBOOT3 
BCPROP1 BCPROP2 BCPROP3 TYPEIERRORRATEBC3 CIWIDTHBC3 empbetaBC3 POWERBC3 IMBALANCEBC3 COVERAGEBC3;


/*ratio mediated*/
/*Percentile bootstrap*/

data perc4; set f;
RGBOOT4=0; LFBOOT4=0;
IF ((&a1*&b1)+(&a2*&b2))/&cp  GT uratio THEN RGBOOT4=1;
IF ((&a1*&b1)+(&a2*&b2))/&cp  LT lratio THEN LFBOOT4=1;

TYPEIERRORRATEBOOTR4=0;
TYPEIERRORRATEBOOTL4=0;
IF ((&a1*&b1)+(&a2*&b2))/&cp=0 && lratio GT 0 && URATIO GT 0 then TYPEIERRORRATEBOOTL4=1;
IF ((&a1*&b1)+(&a2*&b2))/&cp=0 && lratio LT 0 && URATIO LT 0 then TYPEIERRORRATEBOOTR4=1;
TYPEIERRORRATEBOOT4=TYPEIERRORRATEBOOTR4+TYPEIERRORRATEBOOTL4;
IMBALANCEBOOT4=RGBOOT4-LFBOOT4;

CIWIDTHBOOT4=uratio-lratio;
IF ((&a1*&b1)+(&a2*&b2))/&cp GT 0 && lratio LT 0 && uratio GT 0 THEN empbetaB4=1;
ELSE empbetaB4=0;
POWERBOOT4=1-empbetaB4;

IF ((&a1*&b1)+(&a2*&b2))/&cp GT lratio && ((&a1*&b1)+(&a2*&b2))/&cp LT uratio THEN COVERAGEBOOT4=1;
ELSE COVERAGEBOOT4=0;

/*BC bootstrap */
RGBCBOOT4=0; LFBCBOOT4=0;
IF ((&a1*&b1)+(&a2*&b2))/&cp GT BCuratio THEN RGBCBOOT4=1;
IF ((&a1*&b1)+(&a2*&b2))/&cp LT BClratio THEN LFBCBOOT4=1;

TYPEIERRORRATEbcBOOTR4=0;
TYPEIERRORRATEbcBOOTL4=0;
IF ((&a1*&b1)+(&a2*&b2))/&cp=0 && BClratio GT 0 && BCURATIO GT 0 then TYPEIERRORRATEbcBOOTL4=1;
IF ((&a1*&b1)+(&a2*&b2))/&cp=0 && BClratio LT 0 && BCURATIO LT 0 then TYPEIERRORRATEbcBOOTR4=1;
TYPEIERRORRATEBC4=TYPEIERRORRATEbcBOOTR4+TYPEIERRORRATEbcBOOTL4;
IMBALANCEBC4=RGBCBOOT4-LFBCBOOT4;


CIWIDTHBC4=BCuratio-BClratio;
IF ((&a1*&b1)+(&a2*&b2))/&cp GT 0 && BClratio LT 0 && BCuratio GT 0 THEN empbetaBC4=1;
ELSE empbetaBC4=0;
POWERBC4=1-empbetaBC4;

IF ((&a1*&b1)+(&a2*&b2))/&cp GT BClratio && ((&a1*&b1)+(&a2*&b2))/&cp LT BCuratio THEN COVERAGEBC4=1;
ELSE COVERAGEBC4=0;

data perc4;
set perc4;
keep Replicate rgboot4 lfboot4 TYPEIERRORRATEBOOT4 CIWIDTHBOOT4 empbetaB4 POWERBOOT4 IMBALANCEBOOT4 COVERAGEBOOT4 RGBCBOOT4 LFBCBOOT4 TYPEIERRORRATEBC4
CIWIDTHBC4 empbetaBC4 POWERBC4 IMBALANCEBC4 COVERAGEBC4;

data true;
set f;
truen=&nobs;
truea1=&a1;
trueb1=&b1;
truea2=&a2;
trueb2=&b2;
truecp=&cp;

data true;
set true;
keep Replicate truen truea1 trueb1 truea2 trueb2 truecp;

proc sort data=f;
by Replicate;
run;

proc sort data=perc;
by Replicate;
run;

proc sort data=perc2;
by Replicate;
run;

proc sort data=perc3;
by Replicate;
run;

proc sort data=perc4;
by Replicate;
run;

proc sort data=true;
by Replicate;
run;

data ff;
merge f perc perc2 perc3 perc4 true;

*appends results into summary dataset;
data test; set ff;
data new; set summary;
data summary; set new test;

proc means data=SUMMARY noprint;
output out=&file;
run;

%END;
%MEND;
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0,B2=0,CP=0,
FILE=Z1,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.101,B2=0.101,CP=0,
FILE=Z2,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.314,B2=0.314,CP=0,
FILE=Z3,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.577,B2=0.577,CP=0,
FILE=Z4,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0,B2=0,CP=0.131,
FILE=Z5,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.101,B2=0.101,CP=0.131,
FILE=Z6,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.314,B2=0.314,CP=0.131,
FILE=Z7,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.577,B2=0.577,CP=0.131,
FILE=Z8,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0,B2=0,CP=0.4,
FILE=Z9,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.101,B2=0.101,CP=0.4,
FILE=Z10,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.314,B2=0.314,CP=0.4,
FILE=Z11,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.577,B2=0.577,CP=0.4,
FILE=Z12,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0,B2=0,CP=0.74,
FILE=Z13,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.101,B2=0.101,CP=0.74,
FILE=Z14,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.314,B2=0.314,CP=0.74,
FILE=Z15,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0,B1=0,A2=0.577,B2=0.577,CP=0.74,
FILE=Z16,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0,B2=0,CP=0,
FILE=Z17,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0,
FILE=Z18,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0,
FILE=Z19,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=0,
FILE=Z20,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0,B2=0,CP=0.131,
FILE=Z21,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0.131,
FILE=Z22,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0.131,
FILE=Z23,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=0.131,
FILE=Z24,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0,B2=0,CP=0.4,
FILE=Z25,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0.4,
FILE=Z26,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0.4,
FILE=Z27,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=0.4,
FILE=Z28,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0,B2=0,CP=0.74,
FILE=Z29,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.101,B2=0.101,CP=0.74,
FILE=Z30,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.314,B2=0.314,CP=0.74,
FILE=Z31,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.101,B1=0.101,A2=0.577,B2=0.577,CP=0.74,
FILE=Z32,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0,B2=0,CP=0,
FILE=Z33,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0,
FILE=Z34,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0,
FILE=Z35,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=0,
FILE=Z36,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0,B2=0,CP=0.131,
FILE=Z37,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0.131,
FILE=Z38,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0.131,
FILE=Z39,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=0.131,
FILE=Z40,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0,B2=0,CP=0.4,
FILE=Z41,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0.4,
FILE=Z42,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0.4,
FILE=Z43,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=0.4,
FILE=Z44,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0,B2=0,CP=0.74,
FILE=Z45,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.101,B2=0.101,CP=0.74,
FILE=Z46,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.314,B2=0.314,CP=0.74,
FILE=Z47,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.314,B1=0.314,A2=0.577,B2=0.577,CP=0.74,
FILE=Z48,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0,B2=0,CP=0,
FILE=Z49,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0,
FILE=Z50,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0,
FILE=Z51,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=0,
FILE=Z52,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0,B2=0,CP=0.131,
FILE=Z53,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0.131,
FILE=Z54,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0.131,
FILE=Z55,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=0.131,
FILE=Z56,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0,B2=0,CP=0.4,
FILE=Z57,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0.4,
FILE=Z58,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0.4,
FILE=Z59,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=0.4,
FILE=Z60,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0,B2=0,CP=0.74,
FILE=Z61,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.101,B2=0.101,CP=0.74,
FILE=Z62,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.314,B2=0.314,CP=0.74,
FILE=Z63,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);
%SIMULATE(NSIM=1000,NOBS=50,A1=0.577,B1=0.577,A2=0.577,B2=0.577,CP=0.74,
FILE=Z64,TYPE='CCC',ERROR=1,ERRORM1=1,ERRORM2=1,ERRORY=1,nboot=1000);

run;
quit;

data final;
set
	 z1
		z2
		z3
		z4
		z5
		z6
		z7
		z8
		z9
		z10
		z11
		z12
		z13
		z14
		z15
		z16
		z17
		z18
		z19
		z20
		z21
		z22
		z23
		z24
		z25
		z26
		z27
		z28
		z29
		z30
		z31
		z32
		z33
		z34
		z35
		z36
		z37
		z38
		z39
		z40
		z41
		z42
		z43
		z44
		z45
		z46
		z47
		z48
		z49
		z50
		z51
		z52
		z53
		z54
		z55
		z56
		z57
		z58
		z59
		z60
		z61
		z62
		z63
		z64
		;
run;
